==> hermes-6.0.1.31.tar.gz: hermes-6.0.1.31/spec/support/shared_examples/switch_user.rb <==
RSpec.shared_examples_for 'true user only collaborator allowed' do |action|
  it_behaves_like 'true user collaborator allowed'
  it_behaves_like 'true user entity disallowed'
end

RSpec.shared_examples_for 'true user all allowed' do |action|
  it_behaves_like 'true user collaborator allowed'
  it_behaves_like 'true user entity allowed'
end

RSpec.shared_examples_for 'true user collaborator allowed' do |action|
  let!(:collaborator) { create :user, auth_roles: ['collaborateur offre logement'] }
  let!(:target) { create :user, main_applicant_id: applicant.id }
  before do
    token = target.generate_jwt(true_user_id: collaborator.id.to_s)
    request.headers.merge!('Authorization': "Bearer #{token}")
  end
  it "succeeds" do
    action ||= :get
    send(action, *path)
    expect(response).to have_http_status 200
  end
end

RSpec.shared_examples_for 'true user entity allowed' do |action|
  let!(:target) { create :user, main_applicant_id: applicant.id }
  let!(:entreprise) { create :user, auth_roles: ['entreprise'] }
  let!(:entity) { create :entity, readers: [entreprise.id.to_s] }
  let!(:housing_request) { create :active_request, main_applicant_id: applicant.id }
  let!(:entity_form) do
    create(
      :entity_form,
      applicant_id: applicant.id,
      entity_id: entity.id,
      delegation: true,
      delegation_signed: true
    )
  end
  before do
    token = target.generate_jwt(true_user_id: entreprise.id.to_s)
    request.headers.merge!('Authorization': "Bearer #{token}")
  end
  it "succeeds" do
    action ||= :get
    send(action, *path)
    expect(response).to have_http_status 200
  end
end

RSpec.shared_examples_for 'true user entity disallowed' do |action|
  let!(:target) { create :user, main_applicant_id: applicant.id }
  let!(:entreprise) { create :user, auth_roles: ['entreprise'] }
  let!(:entity) { create :entity, readers: [entreprise.id.to_s] }
  let!(:entity_form) do
    create(
      :entity_form,
      applicant_id: applicant.id,
      entity_id: entity.id,
      delegation: true,
      delegation_signed: true
    )
  end
  before do
    token = target.generate_jwt(true_user_id: entreprise.id.to_s)
    request.headers.merge!('Authorization': "Bearer #{token}")
  end
  it "returns unauthorized" do
    action ||= :get
    send(action, *path)
    expect(response).to have_http_status 401
    expect(json['message']).to eq 'Action not allowed'
  end
end

==> hermes-6.0.2.24.tar.gz: hermes-6.0.2.24/spec/support/shared_examples/switch_user.rb <==
RSpec.shared_examples_for 'true user only collaborator allowed' do |action|
  it_behaves_like 'true user collaborator allowed'
  it_behaves_like 'true user entity disallowed'
end

RSpec.shared_examples_for 'true user all allowed' do |action|
  it_behaves_like 'true user collaborator allowed'
  it_behaves_like 'true user entity allowed'
end

RSpec.shared_examples_for 'true user collaborator allowed' do |action|
  let!(:collaborator) { create :user, auth_roles: ['collaborateur offre logement'] }
  let!(:target) { create :user, main_applicant_id: applicant.id }
  before do
    token = target.generate_jwt(true_user_id: collaborator.id.to_s)
    request.headers.merge!('Authorization': "Bearer #{token}")
  end
  it "succeeds" do
    action ||= :get
    send(action, *path)
    expect(response).to have_http_status 200
  end
end

RSpec.shared_examples_for 'true user entity allowed' do |action|
  let!(:target) { create :user, main_applicant_id: applicant.id }
  let!(:entreprise) { create :user, auth_roles: ['entreprise'] }
  let!(:entity) { create :entity, readers: [entreprise.id.to_s] }
  let!(:housing_request) { create :complete_request, main_applicant_id: applicant.id }
  let!(:entity_form) do
    create(
      :entity_form,
      applicant_id: applicant.id,
      entity_id: entity.id,
      delegation: true,
      delegation_signed: true
    )
  end
  before do
    token = target.generate_jwt(true_user_id: entreprise.id.to_s)
    request.headers.merge!('Authorization': "Bearer #{token}")
  end
  it "succeeds" do
    action ||= :get
    send(action, *path)
    expect(response).to have_http_status 200
  end
end

RSpec.shared_examples_for 'true user entity disallowed' do |action|
  let!(:target) { create :user, main_applicant_id: applicant.id }
  let!(:entreprise) { create :user, auth_roles: ['entreprise'] }
  let!(:entity) { create :entity, readers: [entreprise.id.to_s] }
  let!(:entity_form) do
    create(
      :entity_form,
      applicant_id: applicant.id,
      entity_id: entity.id,
      delegation: true,
      delegation_signed: true
    )
  end
  before do
    token = target.generate_jwt(true_user_id: entreprise.id.to_s)
    request.headers.merge!('Authorization': "Bearer #{token}")
  end
  it "returns unauthorized" do
    action ||= :get
    send(action, *path)
    expect(response).to have_http_status 401
    expect(json['message']).to eq 'Action not allowed'
  end
end
